@@ -1,9 +1,9 @@
 ################################
 ### Inverse of the alpha transformation
 #### Tsagris Michail 5/2013
-#### References: Tsagris, M. T., Preston, S., and Wood, A. T. A. (2015). 
+#### References: Tsagris, M. T., Preston, S., and Wood, A. T. A. (2015).
 #### Improved classification for compositional data using the alpha-transformation
-#### http://xxx.tau.ac.il/pdf/1506.04976v2.pdf 
+#### http://xxx.tau.ac.il/pdf/1506.04976v2.pdf
 #### mtsagris@yahoo.gr
 ################################
 
@@ -12,7 +12,7 @@ alfainv <- function(x, a, h = TRUE) {
   ## a is the power parameter
   x <- as.matrix(x)
   D <- ncol(x)
-  if ( D == 1)   x <- t(x) 
+  if ( D == 1)   x <- t(x)
   if (h == TRUE)  {
     h <- helm( D + 1 )  ## multiply with the Helmert
     ## sub-matrix to bring them onto Q^D
@@ -23,7 +23,8 @@ alfainv <- function(x, a, h = TRUE) {
     z <- z / rowSums(z)
   } else {
     ## is a=0, the inverse of the clr is calculated
-    z <- exp(y) / rowSums( exp(y) )
+    ey <- exp(y)
+    z <- ey / rowSums( ey )
   }
   z
-}
\ No newline at end of file
+}
