@@ -6,21 +6,28 @@
 #### The Statistical Analysis of Compositional Data p. 158-160 Blackburn Press
 ################################
 
-comp.reg <- function(y, x, type = "classical", xnew = NULL) {
+comp.reg <- function(y, x, type = "classical", xnew = NULL, yb = NULL) {
   ## y is dependent variable, the compositional data
   ## x is the independent variable(s)
-  ## type takes two values, either 'classical' or
+  ## type takes three values, either 'classical' or
   ## 'spatial' for spatial median regression.
   y <- as.matrix(y)
   y <- y/rowSums(y)  ## makes sure y is compositional data
   x <- as.matrix(x)
+
   ## alr transformation with the first component being the base
-  z <- log( y[, -1] / y[, 1] )
+  if ( is.null(yb) )  {
+    z <- log( y[, -1] / y[, 1] )
+  } else {
+    z <- yb
+  }
+
   if (type == "classical") {
-    mod <- multivreg(z, x, plot = F, xnew = xnew)  ## classical multivariate regression
+    runtime <- proc.time()
+    mod <- multivreg(z, x, plot = FALSE, xnew = xnew)  ## classical multivariate regression
     res <- mod$suma
-    di <- nrow(res[, , 1])
-    beta <- seb <- matrix(nrow = di, ncol = 2)
+    di <- ncol(z)
+    beta <- seb <- matrix(nrow = ncol(x) + 1, ncol = di)
     for (i in 1:di) {
      beta[, i] <- res[, 1, i]
      seb[, i] <- res[, 2, i]
@@ -28,15 +35,18 @@ comp.reg <- function(y, x, type = "classical", xnew = NULL) {
     rownames(seb) <- rownames(beta) <- rownames(res[, , 1])
     colnames(seb) <- colnames(beta) <- colnames(mod$fitted)
     est1 <- mod$est
+    runtime <- proc.time() - runtime
   }
+
   if (type == "spatial") {
     mod <- spatmed.reg(z, x, xnew = xnew)  ## spatial median regression
     beta <- mod$beta
-    seb <- mod$sb
+    seb <- mod$seb
     est1 <- mod$est
+    runtime <- mod$runtime
   }
+
   est2 <- cbind(1, exp(est1))
   est <- est2/rowSums(est2)
-  list(beta = beta, seb = seb, fitted = est)
+  list(runtime = runtime, beta = beta, seb = seb, est = est)
 }
-
