@@ -1,9 +1,9 @@
 ################################
 #### Frechet mean
 #### Tsagris Michail 5/2013
-#### References: Tsagris, M. T., Preston, S., and Wood, A. T. A. (2011). 
+#### References: Tsagris, M. T., Preston, S., and Wood, A. T. A. (2011).
 #### A data-based power transformation for
-#### compositional data. In Proceedings of the 4rth Compositional Data Analysis Workshop, Girona, Spain.  
+#### compositional data. In Proceedings of the 4rth Compositional Data Analysis Workshop, Girona, Spain.
 #### mtsagris@yahoo.gr
 ################################
 
@@ -13,13 +13,15 @@ frechet <- function(x, a) {
   x <- as.matrix(x)  ## makes sure x is a matrix
   x <- x / rowSums(x)  ## makes sure x is compositional data
   if (a == 0) {
-     y <- log(x) - rowMeans(x)
+     xa <- log(x)
+     y <- xa - rowMeans(xa)
      m1 <- colMeans(y)
      m <- exp(m1) / sum( exp(m1) )  ## closed geometric mean
   }  else {
-     z <- x^a / rowSums(x^a)
-     m1 <- colMeans(z)^( 1 / a )
+     xa <- x^a
+     z <- xa / rowSums(xa)
+     m1 <- colMeans(z) ^ ( 1 / a )
      m <- m1 / sum(m1)  ## frechet mean in general
-  }  
+  }
   m
-}
\ No newline at end of file
+}
