@@ -10,6 +10,7 @@ mixnorm.contour <- function(x, mod) {
   ## log-ratio transformation will be used. If type='alr' (the default) the
   ## additive log-ratio transformation is used. If type='ilr', the isometric
   ## log-ratio is used
+
   x <- as.matrix(x)  ## makes sure x is matrix
   x <- x/rowSums(x)  ## make sure x compositional data
   prob <- mod$prob  ## mixing probabilitiy of each cluster
@@ -18,17 +19,19 @@ mixnorm.contour <- function(x, mod) {
   type <- mod$type  ## the type of the log-ratio transformation, either "alr" or "ilr"
   g <- length(mod$prob)  ## how many clusters are there
   n <- 100  ## n is the number of points of each axis used
+  sqrt3 <- sqrt(3)
   x1 <- seq(0.001, 0.999, length = n)
-  x2 <- seq(0.001, sqrt(3)/2 - 1e-04, length = n)
+  x2 <- seq(0.001, sqrt3/2 - 0.001, length = n)
   mat <- matrix(nrow = n, ncol = n)
-  ha <- t( helm (3) )
-  for (i in 1:c(n/2)) {
+  ha <- t( helm(3) )
+
+  for ( i in 1:c(n/2) ) {
     for (j in 1:n) {
-      if (x2[j] < sqrt(3) * x1[i]) {
+      if ( x2[j] < sqrt3 * x1[i] ) {
         ## This checks if the point will lie inside the triangle
         ## The next 4 lines calculate the composition
-        w3 <- (2 * x2[j]) / sqrt(3)
-        w2 <- x1[i] - x2[j] / sqrt(3)
+        w3 <- (2 * x2[j]) / sqrt3
+        w2 <- x1[i] - x2[j] / sqrt3
         w1 <- 1 - w2 - w3
         w <- c(w1, w2, w3)
         if (type == "alr") y <- log( w[-3]/w[3] )  ## alr transformation
@@ -38,7 +41,7 @@ mixnorm.contour <- function(x, mod) {
         }
         ta <- numeric(g)
         for (k in 1:g) {
-          ta[k] <- -0.5 * log(det(2 * pi * su[, , k])) -
+          ta[k] <-  -0.5 * log(det(2 * pi * su[, , k])) -
           0.5 * mahalanobis(y, mu[k, ], su[, , k])
         }
         can <- sum( prob * exp(ta) )
@@ -49,13 +52,13 @@ mixnorm.contour <- function(x, mod) {
     }
   }
 
-  for (i in c(n/2 + 1):n) {
-    for (j in 1:n) {
+  for ( i in c(n/2 + 1):n ) {
+    for ( j in 1:n ) {
       ## This checks if the point will lie inside the triangle
-      if (x2[j] < sqrt(3) - sqrt(3) * x1[i]) {
+      if ( x2[j] < sqrt3 - sqrt3 * x1[i] ) {
         ## The next 4 lines calculate the composition
-        w3 <- (2 * x2[j]) / sqrt(3)
-        w2 <- x1[i] - x2[j] / sqrt(3)
+        w3 <- (2 * x2[j]) / sqrt3
+        w2 <- x1[i] - x2[j] / sqrt3
         w1 <- 1 - w2 - w3
         w <- c(w1, w2, w3)
         if (type == "alr") y <- log( w[-3]/w[3] )  ## alr transformation
@@ -65,23 +68,28 @@ mixnorm.contour <- function(x, mod) {
         }
         ta <- numeric(g)
         for (k in 1:g) {
-          ta[k] <- -0.5 * log(det(2 * pi * su[, , k])) -
+          ta[k] <-  -0.5 * log(det(2 * pi * su[, , k])) -
           0.5 * mahalanobis(y, mu[k, ], su[, , k])
         }
         can <- sum( prob * exp(ta) )
-        if (abs(can) < Inf) {
+        if ( abs(can) < Inf ) {
           mat[i, j] <- can
         } else  mat[i, j] <- NA
       }
     }
   }
 
-  contour(x1, x2, mat, col = 3)
+  contour( x1, x2, mat, nlevels = 7, col = 3, pty = "s", xaxt = "n", yaxt = "n", bty = "n" )
   b1 <- c(1/2, 0, 1, 1/2)
-  b2 <- c(sqrt(3)/2, 0, 0, sqrt(3)/2)
+  b2 <- c( sqrt3/2, 0, 0, sqrt3/2 )
   b <- cbind(b1, b2)
   points(b[ , 1], b[ , 2] , type = "l", xlab = " ", ylab = " ")
-  proj <- matrix(c(0, 1, 1/2, 0, 0, sqrt(3)/2), ncol = 2)
+  nam <- colnames(x)
+  if ( is.null(nam) )  nam <- paste("X", 1:3, sep = "") 
+  text( b[1, 1], b[1, 2] + 0.02, nam[3], cex = 1 )
+  text( b[2:3, 1], b[2:3, 2] - 0.02, nam[1:2], cex = 1 )
+  proj <- matrix(c(0, 1, 1/2, 0, 0, sqrt3/2), ncol = 2)
   xa <- x %*% proj
   points(xa[, 1], xa[, 2])
+
 }
