@@ -1,6 +1,6 @@
 ################################
 #### Symmetric Dirichlet distribution
-#### Tsagris Michail 11/2013  
+#### Tsagris Michail 11/2013
 #### mtsagris@yahoo.gr
 ################################
 
@@ -8,11 +8,12 @@ sym.test <- function(x) {
   ## x contains the data
   n <- nrow(x)  ## the sample size
   D <- ncol(x)  ## the dimensionality of the data
-   sym <- function(a, x) {
-    n * lgamma(D * a) - n * D * lgamma(a) + 
-    sum( log(x) * (a - 1) )
+  zx <- log(x)
+   sym <- function(a, zx) {
+    n * lgamma(D * a) - n * D * lgamma(a) +
+    sum( zx * (a - 1) )
    }
-  t0 <- optimize(sym, c(0, 1000), x = x, maximum = TRUE)
+  t0 <- optimize(sym, c(0, 1000), zx = zx, maximum = TRUE)
   t1 <- diri.nr(x)
   a0 <- t0$maximum
   a1 <- t1$param
@@ -20,6 +21,7 @@ sym.test <- function(x) {
   h0 <- as.numeric(t0$objective)
   test <- 2 * (h1 - h0)
   pvalue <- 1 - pchisq(test, D - 1)
+
   if ( is.null(colnames(x)) ) {
     names(a1) <- paste("X", 1:D, sep = "")
   } else  names(a1) <- colnames(x)
